@@ -1,7 +1,7 @@
 package Perinci::Sub::To::CLIDocData;
 
-our $DATE = '2015-09-23'; # DATE
-our $VERSION = '0.23'; # VERSION
+our $DATE = '2015-12-17'; # DATE
+our $VERSION = '0.24'; # VERSION
 
 use 5.010001;
 use strict;
@@ -436,7 +436,7 @@ sub gen_cli_doc_data_from_meta {
                 } else {
                     require Perinci::Sub::ConvertArgs::Argv;
                     my $res = Perinci::Sub::ConvertArgs::Argv::convert_args_to_argv(
-                        args => $eg->{args}, meta => $meta);
+                        args => $eg->{args}, meta => $meta, use_pos => 1);
                     return err($res, 500, "Can't convert args to argv")
                         unless $res->[0] == 200;
                     $argv = $res->[2];
@@ -479,7 +479,7 @@ Perinci::Sub::To::CLIDocData - From Rinci function metadata, generate structure
 
 =head1 VERSION
 
-This document describes version 0.23 of Perinci::Sub::To::CLIDocData (from Perl distribution Perinci-Sub-To-CLIDocData), released on 2015-09-23.
+This document describes version 0.24 of Perinci::Sub::To::CLIDocData (from Perl distribution Perinci-Sub-To-CLIDocData), released on 2015-12-17.
 
 =head1 SYNOPSIS
 
@@ -651,6 +651,8 @@ which are applicable to CLI environment and format them.
 The resulting data structure is convenient to use when one wants to produce a
 documentation for CLI program (including help/usage message and POD).
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
